<?php

namespace Litecms\Exchangeorder\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Exchangeorder\Http\Requests\ExchangeorderRequest;
use Litecms\Exchangeorder\Interfaces\ExchangeorderRepositoryInterface;
use Litecms\Exchangeorder\Models\Exchangeorder;

/**
 * Resource controller class for exchangeorder.
 */
class ExchangeorderResourceController extends BaseController
{

    /**
     * Initialize exchangeorder resource controller.
     *
     * @param type ExchangeorderRepositoryInterface $exchangeorder
     *
     * @return null
     */
    public function __construct(ExchangeorderRepositoryInterface $exchangeorder)
    {
        parent::__construct();
        $this->repository = $exchangeorder;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Exchangeorder\Repositories\Criteria\ExchangeorderResourceCriteria::class);
    }

    /**
     * Display a list of exchangeorder.
     *
     * @return Response
     */
    public function index(ExchangeorderRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Exchangeorder\Repositories\Presenter\ExchangeorderPresenter::class)
                ->$function();
        }

        $exchangeorders = $this->repository->paginate();

        return $this->response->title(trans('exchangeorder::exchangeorder.names'))
            ->view('exchangeorder::exchangeorder.index', true)
            ->data(compact('exchangeorders'))
            ->output();
    }

    /**
     * Display exchangeorder.
     *
     * @param Request $request
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function show(ExchangeorderRequest $request, Exchangeorder $exchangeorder)
    {

        if ($exchangeorder->exists) {
            $view = 'exchangeorder::exchangeorder.show';
        } else {
            $view = 'exchangeorder::exchangeorder.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('exchangeorder::exchangeorder.name'))
            ->data(compact('exchangeorder'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new exchangeorder.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ExchangeorderRequest $request)
    {

        $exchangeorder = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('exchangeorder::exchangeorder.name')) 
            ->view('exchangeorder::exchangeorder.create', true) 
            ->data(compact('exchangeorder'))
            ->output();
    }

    /**
     * Create new exchangeorder.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ExchangeorderRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $exchangeorder                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('exchangeorder::exchangeorder.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/exchangeorder/exchangeorder'))
                ->redirect();
        }

    }

    /**
     * Show exchangeorder for editing.
     *
     * @param Request $request
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function edit(ExchangeorderRequest $request, Exchangeorder $exchangeorder)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('exchangeorder::exchangeorder.name'))
            ->view('exchangeorder::exchangeorder.edit', true)
            ->data(compact('exchangeorder'))
            ->output();
    }

    /**
     * Update the exchangeorder.
     *
     * @param Request $request
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function update(ExchangeorderRequest $request, Exchangeorder $exchangeorder)
    {
        try {
            $attributes = $request->all();

            $exchangeorder->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('exchangeorder::exchangeorder.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the exchangeorder.
     *
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function destroy(ExchangeorderRequest $request, Exchangeorder $exchangeorder)
    {
        try {

            $exchangeorder->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('exchangeorder::exchangeorder.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('exchangeorder/exchangeorder/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('exchangeorder/exchangeorder/' . $exchangeorder->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple exchangeorder.
     *
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function delete(ExchangeorderRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('exchangeorder::exchangeorder.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('exchangeorder/exchangeorder'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/exchangeorder/exchangeorder'))
                ->redirect();
        }

    }

    /**
     * Restore deleted exchangeorders.
     *
     * @param Model   $exchangeorder
     *
     * @return Response
     */
    public function restore(ExchangeorderRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('exchangeorder::exchangeorder.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/exchangeorder/exchangeorder'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/exchangeorder/exchangeorder/'))
                ->redirect();
        }

    }

}
